<?php

namespace Sit\Package\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sit\Package\Models\Package;

class PackagePolicy
{

    /**
     * Determine if the given user can view the package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function view(UserPolicy $user, Package $package)
    {
        if ($user->canDo('package.package.view') && $user->isAdmin()) {
            return true;
        }

        return $package->user_id == user_id() && $package->user_type == user_type();
    }

    /**
     * Determine if the given user can create a package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('package.package.create');
    }

    /**
     * Determine if the given user can update the given package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function update(UserPolicy $user, Package $package)
    {
        if ($user->canDo('package.package.edit') && $user->isAdmin()) {
            return true;
        }

        return $package->user_id == user_id() && $package->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Package $package)
    {
        return $package->user_id == user_id() && $package->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Package $package)
    {
        if ($user->canDo('package.package.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given package.
     *
     * @param UserPolicy $user
     * @param Package $package
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Package $package)
    {
        if ($user->canDo('package.package.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
