<?php

namespace Sit\Package\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sit\Package\Models\PackagesCategory;

class PackagesCategoryPolicy
{

    /**
     * Determine if the given user can view the packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, PackagesCategory $packages_category)
    {
        if ($user->canDo('package.packages_category.view') && $user->isAdmin()) {
            return true;
        }

        return $packages_category->user_id == user_id() && $packages_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('package.packages_category.create');
    }

    /**
     * Determine if the given user can update the given packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, PackagesCategory $packages_category)
    {
        if ($user->canDo('package.packages_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $packages_category->user_id == user_id() && $packages_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PackagesCategory $packages_category)
    {
        return $packages_category->user_id == user_id() && $packages_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PackagesCategory $packages_category)
    {
        if ($user->canDo('package.packages_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given packages_category.
     *
     * @param UserPolicy $user
     * @param PackagesCategory $packages_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PackagesCategory $packages_category)
    {
        if ($user->canDo('package.packages_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
