<?php

namespace Sit\Package\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Sit\Package\Models\Package;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Sit\Package\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/package/package/*')) {
            Route::bind('package', function ($package) {
                $packagerepo = $this->app->make('Sit\Package\Interfaces\PackageRepositoryInterface');
                return $packagerepo->findorNew($package);
            });
        }
        if (Request::is('*/package/packages_category/*')) {
            Route::bind('packages_category', function ($packages_category) {
                $packages_categoryrepo = $this->app->make('Sit\Package\Interfaces\PackagesCategoryRepositoryInterface');
                return $packages_categoryrepo->findorNew($packages_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
